var structsdbus_1_1IConnection_1_1PollData =
[
    [ "getPollTimeout", "structsdbus_1_1IConnection_1_1PollData.html#a73e9ba9d09dcdd721a419e351987e481", null ],
    [ "getRelativeTimeout", "structsdbus_1_1IConnection_1_1PollData.html#a9dfe75bea788ad72c6363666b4618867", null ],
    [ "eventFd", "structsdbus_1_1IConnection_1_1PollData.html#a68728ca95769cd68b75e58a2537eed40", null ],
    [ "events", "structsdbus_1_1IConnection_1_1PollData.html#a252fc9b3ea4b2764ff4f7dcb90b4debf", null ],
    [ "fd", "structsdbus_1_1IConnection_1_1PollData.html#a7d51e88c0600c2a3b8860181d360fd42", null ],
    [ "timeout", "structsdbus_1_1IConnection_1_1PollData.html#ac0b05bd1292115b752f3514b1d92cfaa", null ]
];